@@ -24,7 +24,6 @@
 #include "bakery/bakery.h"
 #include "frame_glom.h"
 
-
 class App_Glom : public Bakery::App_WithDoc_Gtk
 {
 public:
@@ -39,8 +38,6 @@ public:
   /// Get the UIManager so we can merge new menus in.
   Glib::RefPtr<Gtk::UIManager> get_ui_manager();
 
-  virtual void on_database_selected(bool database_selected);
-
   /** Changes the mode to Data mode, as if the user had selected the Data Mode menu item.
    */
   virtual void set_mode_data();
@@ -49,8 +46,10 @@ public:
     
 protected:
   virtual void init_layout(); //override.
+  virtual void init_menus_file(); //override.
   virtual void init_menus(); //override.
   virtual void init_menus_help(); //override
+  virtual void init_toolbars(); //override
   virtual void init_create_document(); //override
   virtual void on_document_load(); //override.
 
@@ -72,7 +71,6 @@ protected:
 
   typedef std::list< Glib::RefPtr<Gtk::Action> > type_listActions; 
   type_listActions m_listDeveloperActions; //Only enabled when in developer mode.
-  type_listActions m_listWithDatabaseActions;  //Only enabled when a database has been selected.
   Glib::RefPtr<Gtk::Action> m_action_mode_data;
   Glib::RefPtr<Gtk::RadioAction> m_action_menu_userlevel_developer, m_action_menu_userlevel_operator;
   
