@@ -132,6 +132,10 @@ sharedptr<SharedConnection> ConnectionPool::connect()
         //m_GdaDataSourceInfo->
 
         Glib::ustring cnc_string = "USER=" + m_user + ";PASSWORD=" + m_password; //TODO: Host
+      
+        if(!m_database.empty())
+          cnc_string += (";DATABASE=" + m_database);
+
         //std::cout << "connecting: cnc string: " << cnc_string << std::endl;
 
         //*m_refGdaConnection = m_GdaClient->open_connection(m_GdaDataSourceInfo.get_name(), m_GdaDataSourceInfo.get_username(), m_GdaDataSourceInfo.get_password() );
@@ -140,9 +144,16 @@ sharedptr<SharedConnection> ConnectionPool::connect()
         {
           //g_warning("ConnectionPool: connection opened");
           
-           //Create the fieldtypes member if it has not already been done:
+          //Create the fieldtypes member if it has not already been done:
           if(!m_pFieldTypes)
             m_pFieldTypes = new FieldTypes(m_refGdaConnection);
+            
+          //Open the database, if one has been specified:
+          /* This does not seem to work in libgda's postgres provider, so we specify it in the cnc_string instead:
+          std::cout << "  database = " << m_database << std::endl;
+          if(!m_database.empty())
+            m_refGdaConnection->change_database(m_database);
+          */
           
           return connect(); //Call this method recursively. This time m_refGdaConnection exists.
         }
@@ -177,6 +188,11 @@ void ConnectionPool::set_password(const Glib::ustring& value)
   m_password = value;
 }
 
+void ConnectionPool::set_database(const Glib::ustring& value)
+{
+  m_database = value;
+}
+
 Glib::ustring ConnectionPool::get_host() const
 {
   return m_host;
@@ -192,6 +208,11 @@ Glib::ustring ConnectionPool::get_password() const
   return m_password;
 }
 
+Glib::ustring ConnectionPool::get_database() const
+{
+  return m_database;
+}
+
 const FieldTypes* ConnectionPool::get_field_types() const
 {
   return m_pFieldTypes;
