@@ -131,7 +131,7 @@ Glib::ustring GlomConversions::get_text_for_gda_value(Field::glom_field_type glo
   if(glom_type == Field::TYPE_DATE)
   {
     Gnome::Gda::Date gda_date = value.get_date();
-
+    
     tm the_c_time = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
     the_c_time.tm_year = gda_date.year - 1900; //C years start are the AD year - 1900. So, 01 is 1901.
     the_c_time.tm_mon = gda_date.month - 1; //C months start at 0.
@@ -193,33 +193,36 @@ Glib::ustring GlomConversions::get_text_for_gda_value(Field::glom_field_type glo
   }
 }
 
-Gnome::Gda::Value GlomConversions::parse_value(Field::glom_field_type glom_type, const Glib::ustring& text,  bool& success)
+Gnome::Gda::Value GlomConversions::parse_value(Field::glom_field_type glom_type, const Glib::ustring& text, bool& success, bool iso_format)
 {
+  std::locale the_locale = (iso_format ? std::locale::classic() :  std::locale("") /* The user's current locale */);
+  
   //Put a NULL in the database for empty dates, times, and numerics, because 0 would be an actual value.
   //But we use "" for strings, because the distinction between NULL and "" would not be clear to users.
   if(text.empty())
   {
-    if( (glom_type ==  Field::TYPE_DATE) || (glom_type ==  Field::TYPE_TIME) || (glom_type ==  Field::TYPE_NUMERIC) )
+    if( (glom_type == Field::TYPE_DATE) || (glom_type ==  Field::TYPE_TIME) || (glom_type ==  Field::TYPE_NUMERIC) )
     {
       Gnome::Gda::Value null_value;
+      success = true;
       return null_value;
     }
   }
 
   if(glom_type == Field::TYPE_DATE)
   {
-    tm the_c_time = parse_date(text, success);
+    tm the_c_time = parse_date(text, the_locale, success);
 
     Gnome::Gda::Date gda_date = {0, 0, 0};
     gda_date.year = the_c_time.tm_year + 1900; //The C time starts at 1900.
     gda_date.month = the_c_time.tm_mon + 1; //The C month starts at 0.
     gda_date.day = the_c_time.tm_mday; //THe C mday starts at 1.
-  
+
     return Gnome::Gda::Value(gda_date);
   }
   else if(glom_type == Field::TYPE_TIME)
   {
-    tm the_c_time = parse_time(text, success);
+    tm the_c_time = parse_time(text, the_locale, success);
 
     Gnome::Gda::Time gda_time = {0, 0, 0, 0};
     gda_time.hour = the_c_time.tm_hour;
@@ -232,7 +235,7 @@ Gnome::Gda::Value GlomConversions::parse_value(Field::glom_field_type glom_type,
   {
     //Try to parse the inputted number, according to the current locale.
     std::stringstream the_stream;
-    the_stream.imbue( std::locale("") /* The user's current locale */ ); //Parse it as per the current locale.
+    the_stream.imbue( the_locale ); //Parse it as per the current locale.
     the_stream.str(text); //Avoid << because it does implicit character conversion (though that might not be a problem here. Not sure). murrayc
     double the_number = 0;
     the_stream >> the_number;  //TODO: Does this throw any exception if the text is an invalid time?
@@ -257,6 +260,11 @@ Gnome::Gda::Value GlomConversions::parse_value(Field::glom_field_type glom_type,
     success = true; //Can this ever fail?
     return Gnome::Gda::Value(&gda_numeric);
   }
+  else if(glom_type == Field::TYPE_BOOLEAN)
+  {
+    success = true;
+    return Gnome::Gda::Value( (text == "TRUE" ? true : false) ); //TODO: Internationalize this, but it should never be used anyway.
+  }
 
   success = true;
   return Gnome::Gda::Value(text);
