@@ -174,6 +174,8 @@ void Box_Tables::fill_from_database()
 
 void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
+  //TODO: Handle cell renderer changes to prevent illegal table names (e.g. starting with numbers.)"
+  
   Glib::ustring table_name = m_AddDel.get_value(row, m_colTableName);
   if(!table_name.empty())
   {
@@ -186,7 +188,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 
     //PostgresSQL:
     //Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " serial NOT NULL  PRIMARY KEY)" );
-    Query_execute( "CREATE TABLE " + table_name + " (" + primary_key_name + " numeric NOT NULL  PRIMARY KEY)" );
+    Query_execute( "CREATE TABLE \"" + table_name + "\" (" + primary_key_name + " numeric NOT NULL  PRIMARY KEY)" );
 
     //Show the new information for this whole row:
     TableInfo table_info;
